clear
#delimit;
set mem 100m;

***check wages, using both duration & time-in/out for hours***;

local dirn "052810 060609 062509 070210 080310 082009 090410 092909 100110 101209 112809";
foreach x of local dirn {;

	disp "";
	disp "*-------------------------------------*";
	disp "*--------Working on file `x'----------*";
	disp "*-------------------------------------*";
	use chkm`x', clear;
	
	***find average time ranges***;
	gen timein = hh(time_in) + mm(time_in)/60;
	gen timeout = hh(time_out) + mm(time_out)/60;
	summ timein timeout, detail; 

	***combine job-piece and employee-piece info if both present***;
	local vep "pieces duration wages minpcs piece_rate hourly_rate payment flagjobv";
	foreach var of local vep {;
		capture replace `var'=`var'ep if `var' == . & `var'ep ~= .; *does nothing if only employee-pieces. skipped if only job-piece;
		capture ren `var'ep `var'; *rename employee-piece vars if job-piece not present. otherwise skipped.*;
	};
	
	***some consistency cleaning***;
	drop if payment == .; *some are paid by time only;
	drop if pieces == 0; *some very low wages because pieces=0 99/3/09 VG;
	replace hourly_rate = 8 if hourly_rate ~= 8;
	replace duration = duration/60;
	capture gen disc = .; *since not all files had job-piece & emp-piece;
	
	***exceed minimum***;
	gen excmind = pieces >= duration*minpcs if payment == 1 | payment == 2;
	replace excmind = wages/duration >= 8 if payment == 3;
	label var excmind "exceed minimum pieces per hour based on duration";

	***daily wages (already computed for payment=3)***;
	gen wagesd = duration*hourly_rate + max(pieces-minpcs*duration,0)*piece_rate if payment == 1;
	replace wagesd = duration*hourly_rate + pieces*piece_rate*excmind if payment == 2;

	***censored hourly wage***;
	gen hrlywagedc = wagesd/duration if payment == 1 | payment == 2;
	replace hrlywagedc = max(wages/duration,8) if payment == 3;
	label var hrlywagedc "censored hourly wage based on duration";

	***uncensored hourly pieces for non-job switchers (in day)***;
	gen hrlypiecedu = pieces/duration if flagjobv ~= 1;
	label var hrlypiecedu "uncensored hourly pieces based on duration (non-job switchers)";

	compress;
	save chkm_combine`x', replace;
	
};

***append files***;
local dirn "060609 062509 070210 080310 082009 090410 092909 100110 101209 112809";
*all obs*;
use chkm_combine052810, clear;
foreach x of local dirn {;
	append using chkm_combine`x';
	rm chkm_combine`x'.dta;
};
rm chkm_combine052810.dta;
save chkm_combine, replace;
