clear
#delimit;
set mem 300m;

***daily summary measures for pollution data closest to Lagomarsino***;
capture log close;
log using poll09sum.log, replace;

use poll09, clear;
capture destring site, replace;

***keep certain monitors***;
keep if site == XXXX | site == YYYY;

***rename quality vars & assign label***;
for var quality_OZONE quality_PM25HR \ new qozone qpm25: ren X Y;

***keep only valid observations***;
tab1 q*, nol m;
foreach var of varlist ozone pm25 {;
	tabstat `var', by(q`var') s(mean count) missing;
};
summ ozone pm25;
for var qozone qpm25 \ var ozone pm25: replace Y = . if (X ~= 0 & X ~= . & X ~= -9) & Y ~= .;
summ ozone pm25;
drop q*;

***compute daily measure for ave day (6-3)***;
keep if hour >= 6 & hour <= 15;
foreach var of varlist ozone pm25 {;
	egen `var'max6t15_s = max(`var'), by(site date);
	egen `var'min6t15_s = min(`var'), by(site date);
	egen `var'ave6t15_s = mean(`var'), by(site date);
};

***keep 1 obs per date***;
sort site date ozonemax6t15_s;
by site date: keep if _n == 1;
drop hour ozone pm25;

***reshape to date by site***;
capture drop name;
drop monitor prelim*;
reshape wide ozone* pm25*, i(date) j(site);

***drop if completely missing***;
foreach var of varlist ozone* pm25* {;
	summ `var';
	if r(N) == 0 {;
		drop `var';
	};
};

***final cleaning***;
compress;
sort date;
save poll09sum, replace;

capture log close;