clear
#delimit;
set mem 300m;

***read in pollution data & merge into one file***;
capture log close;
log using poll10.log, replace;

***read in each pollutant - RENAME AS APPROPRIATE in the insheet line (line 16)***;
***NOTE: data was downloaded quarterly, make adjustments in 'numlist' below as appropriate***;
local pn "OZONE_ppb PM25HR";
foreach var1 of local pn {;
	
	foreach q of numlist 1/4 {;
	
		insheet using raw/`var1'_q`q'.csv, comma clear names;
		drop in -9/l;
		foreach var of varlist variable units obs_type flag {;
			tab `var', m;
			drop `var';
		};
		drop name latit longit monitoring;
		gen datev = date(date, "ymd");
		drop date;
		ren datev date;
		format date %d;
		ren start hour;
		ren value `var1';
		replace `var1' = . if `var1' < 0;
		ren quality quality_`var1';
		ren prelim prelim_`var1';
		replace quality = -9 if quality == .;
		sort site date hour;
		compress;
		save `var1'`q', replace;

	};

};

***append into year***;
local pn "OZONE_ppb PM25HR";
foreach var1 of local pn {;
	use `var1'1, clear;
	foreach q of numlist 2/4 {;
		append using `var1'`q';
		erase `var1'`q'.dta;
	};
	compress;
	sort site date hour;
	save `var1', replace;
	erase `var1'1.dta;
};

***merge pollutants***;
local pn "PM25HR";
use OZONE_ppb, clear;
foreach var1 of local pn {;
	sort site date hour;
	merge site date hour using `var1';
	tab _m;
	drop _m;
	erase `var1'.dta;
};
erase OZONE_ppb.dta;

***clean variable names***;
order site date hour;
ren OZONE_ppb ozone;
ren PM25HR pm25;
label var ozone "Ozone (ppb)";
label var pm25 "PM 2.5 using BAM (ug/m3)";

***quality label***;
label define qual 0 "valid observation" 1 "the data supplier marked the observation as suspect, but it is still valid" 
	2 "the automated qa routine judged the observation questionable and invalid" 3 "the automated qa routine judged the 
	observation invalid" 4 "the data supplier flagged the observation invalid" 5 "the observation was flagged invalid 
	manually" -9 "no quality code reported";
local pn "OZONE_ppb PM25HR";
foreach var1 of local pn {;
	label values quality_`var1' qual;
};

***drop if no data***;
egen nobs = rmiss(ozone pm25);
tab nobs;
drop if nobs == 2;
drop nobs;

compress;
sort site date hour;
save poll10, replace;

log close;
