clear
#delimit;
set mem 800m;
set matsize 2800;
set more off;

***table 3 - columns 1 & 2 w/ SEs, col 3 & 4 w/o SEs, which are in table3b & table 3c***;
local fn "table3a";
local dv "ystd";
local ss "ave";
capture log close;
log using `fn'.log, replace;

use prep4reg, clear;

***group covariates***;
local wavevars "tavebdum* apave6t15_sXXXX windsave6t15_sXXXX solradave6t15_sXXXX precave6t15_sXXXX dpavebdum* srave_* pm25ave6t15_sXXXX";
local xcov "dowdum* yeardum* pdum* ndays ndays2 male female";

***setup outeg***;
qui reg ystd ozoneave6t15_sXXXX;
outreg2 using `fn'_ave.out, replace se text bracket ctitle("setup") nolabel;

***linear***;
cgmreg ystd ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
outreg2 using `fn'_ave.out, append se text bracket ctitle("OLS") nolabel bdec(3) addstat(mdv, `pp');

***tobit***;
tobit2 ystd ozoneave6t15_sXXXX `wavevars' `xcov', fcluster(date) tcluster(employee) ll(0);
outreg2 using `fn'_ave.out, append se text bracket ctitle("tobit") nolabel bdec(3);
tobit ystd ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date) ll(0); *for r-squared;

***median - no cluster***;
qreg ystd ozoneave6t15_sXXXX `wavevars' `xcov';
outreg2 using `fn'_ave.out, append se text bracket ctitle("median") nolabel bdec(3);

***cqr - no cluster***;
***piece rate regime - CQR .5***;
local x = "ozoneave6t15_sXXXX `xcov' `wavevars'";
* quantile, c, deltan *;
local q "10";
local q2 "3";
local tau "50";

**************;
***1st step***;
**************;
qui probit excmind `x';
capture drop not;
predict not;
		
capture drop cutoff;
egen cutoff=pctile(not) if not>(1-(`tau'/100)), p(`q');
qui sum cutoff;
disp "value of c for dependent variable " r(mean)-(1-(`tau'/100));
		
*Keep in j0 if the predicted value is larger than the cutoff value;
capture drop j0;
gen j0=(not>cutoff);
*The mean is the percent of the observations that have been selected for j0;
qui sum j0;
disp "percent of obs chosen for j0 " r(mean);

**************;
***2nd step***;
**************;
qui qreg ystd `x' if j0, quantile(`tau');
capture drop yhat;
predict yhat;
		
capture drop cutoff2;
egen cutoff2=pctile(yhat) if yhat>0, p(`q2');
*Report the value of deltan - would be different if I hadn't transformed the data to be censored at zero
disp "value of deltan " cutoff2;
  	
*Keep in j1 if the predicted value is larger than cutoff2;
capture drop j1;
gen j1=(yhat>cutoff2);
sum j1;
capture drop pctj1;
gen pctj1=r(mean)*100;
  	
*Check:  Is j0 a subset of j1?;
*What percent of observations in j0 are in j1;
qui count if j0;
local j0num=r(N);
qui count if j0 & j1;
local j1num=r(N);
disp "percent of obs in j0 also in j1 " (`j1num'/`j0num');
*How many observations are in j1 but not j0;
qui count if j1==1 & j0==0;
disp "number of obs in j1 but not j0 " r(N);

**************;
***3rd step***;
**************;
di "********results for quantile = `tau'**********";
qreg ystd `x' if j1, quantile(`tau');
outreg2 using `fn'_ave.out, append se text bracket ctitle("cqr") nolabel bdec(3);

capture log close;
set more on;
