clear
#delimit;
set mem 1300m;
set matsize 2800;
set more off;

***Table 4, col 5-8***;
local fn "table4b";
capture log close;
log using `fn'.log, replace;

use prep4reg, clear;

***group covariates***;
local wavevars "tavebdum* apave6t15_sXXXX windsave6t15_sXXXX solradave6t15_sXXXX precave6t15_sXXXX dpavebdum* srave_* pm25ave6t15_sXXXX";
local xcov "dowdum* yeardum* pdum* ndays ndays2 male female";

***create lags***;
duplicates drop employee date, force;
tsset employee date;
foreach var of varlist ystd ozoneave6t15_sXXXX `wavevars' {;
	gen l1`var' = L1.`var';
	gen l2`var' = L2.`var';
};
local l1wavevars "l1tavebdum* l1apave6t15_sXXXX l1windsave6t15_sXXXX l1solradave6t15_sXXXX l1precave6t15_sXXXX l1dpavebdum* l1srave_* l1pm25ave6t15_sXXXX";
local l2wavevars "l2tavebdum* l2apave6t15_sXXXX l2windsave6t15_sXXXX l2solradave6t15_sXXXX l2precave6t15_sXXXX l2dpavebdum* l2srave_* l2pm25ave6t15_sXXXX";

***setup outeg***;
qui reg ystd ozoneave6t15_sXXXX l1ozoneave6t15_sXXXX l2ozoneave6t15_sXXXX;
outreg2 using `fn'_ave.out, replace se text bracket ctitle("setup") nolabel;

***col 5 - 1 lag productivity not missing***;
cgmreg ystd ozoneave6t15_sXXXX `wavevars' `xcov' if l1ozoneave6t15_sXXXX ~= ., cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
outreg2 using `fn'_ave.out, append se text bracket ctitle("1lag nm") nolabel addstat(mdv, `pp');

***col 6 - 1 lag***;
cgmreg ystd ozoneave6t15_sXXXX l1ozoneave6t15_sXXXX `wavevars' `xcov' if l1ozoneave6t15_sXXXX ~= ., cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
lincom ozoneave6t15_sXXXX + l1ozoneave6t15_sXXXX;
outreg2 using `fn'_ave.out, append se text bracket ctitle("1lag") nolabel addstat(mdv, `pp');

***col 7 - 2 lag productivity not missing***;
cgmreg ystd ozoneave6t15_sXXXX `wavevars' `xcov' if l1ozoneave6t15_sXXXX ~= . & l2ozoneave6t15_sXXXX ~= ., cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
outreg2 using `fn'_ave.out, append se text bracket ctitle("2lag nm") nolabel addstat(mdv, `pp');

***col 8 - 2 lag***;
cgmreg ystd ozoneave6t15_sXXXX l1ozoneave6t15_sXXXX l2ozoneave6t15_sXXXX `wavevars' `xcov' if l1ozoneave6t15_sXXXX ~= . & l2ozoneave6t15_sXXXX ~= ., cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
lincom ozoneave6t15_sXXXX + l1ozoneave6t15_sXXXX + l2ozoneave6t15_sXXXX;
outreg2 using `fn'_ave.out, append se text bracket ctitle("2lag") nolabel addstat(mdv, `pp');

capture log close;
set more on;

